==> cenote_0.9.1_20071020.zip: cenote/widget/edit_button/edit_button.php <==
<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4 foldmethod=marker: */
// +------------------------------------------------------------------------+
// | Application: Cenote CMS												|
// +------------------------------------------------------------------------+
// | Copyright: (c) 2007.9 Akira Tanaka										|
// +------------------------------------------------------------------------+
// | 利用に関して: /cenote.txtを参照してください。							|
// +------------------------------------------------------------------------+
// | Author: Original Author <akirat28@gmail.com>							|
// +------------------------------------------------------------------------+
//

/**
 * editButton class
 *
 * エディットボタンを表示するウィジット
 *
 */

class edit_button {
	public function display(){
		$html = "";
		if($_SESSION['edit_button'] || $_SESSION['mnt_button']){
			$html .= "<div id=\"cenote_edit_menu\"><p id=\"cenote_edit_menu\">メンテナンスメニュー</p>";
		}
		if($_SESSION['edit_button'] == "fckeditor"){
			$html .= "<li id=\"cenote_edit_menu\"><span class=\"white_color\">
						<a href=\"index.php?mod=AdminTool&page=8\">デザイン修正</a>
						</li>";
		}
		if($_SESSION['edit_button'] == "editor"){
			$html .= "<li id=\"cenote_edit_menu\"><span class=\"white_color\">
						<a href=\"index.php?mod=AdminTool&page=9\">デザイン修正</a>
						</li>";
		}
		if($_SESSION['mnt_button']){
			$html .= "<li id=\"cenote_edit_menu\"><span class=\"white_color\">
						<a href=\"index.php?mod=AdminTool&page=7".
						$_SESSION['mnt_button'].
						"\">メンテナンス</a></li>";
		}
		if($_SESSION['edit_button'] || $_SESSION['mnt_button']){
			$html .= "</div>";
		}
		return $html;
	}
}

==> cenote_0.9.3_20071026.zip: cenote/widget/edit_button/edit_button.php <==
<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4 foldmethod=marker: */
// +------------------------------------------------------------------------+
// | Application: Cenote CMS												|
// +------------------------------------------------------------------------+
// | Copyright: (c) 2007.9 Akira Tanaka										|
// +------------------------------------------------------------------------+
// | 利用に関して: /cenote.txtを参照してください。							|
// +------------------------------------------------------------------------+
// | Author: Original Author <akirat28@gmail.com>							|
// +------------------------------------------------------------------------+
//

/**
 * editButton class
 *
 * エディットボタンを表示するウィジット
 *
 */

class edit_button {
	public function display(){
		$html = "";
		if($_SESSION['edit_button'] || $_SESSION['mnt_button']){
			$html .= "<table class=\"cenote_edit\"><tr class=\"cenote_edit\"><th class=\"cenote_edit\">メンテナンスメニュー</th>";
		}
		if($_SESSION['edit_button'] == "fckeditor"){
			$html .= "<tr class=\"cenote_edit\"><td class=\"cenote_edit\"><span class=\"white_color\">
						<a href=\"index.php?mod=AdminTool&page=8\">デザイン修正</a>
						</td></tr>";
		}
		if($_SESSION['edit_button'] == "editor"){
			$html .= "<tr class=\"cenote_edit\"><td class=\"cenote_edit\"><span class=\"white_color\">
						<a href=\"index.php?mod=AdminTool&page=9\">デザイン修正</a>
						</td></tr>";
		}
		if($_SESSION['mnt_button']){
			$html .= "<tr class=\"cenote_edit\"><td class=\"cenote_edit\"><span class=\"white_color\">
						<a href=\"index.php?mod=AdminTool&page=7".
						$_SESSION['mnt_button'].
						"\">メンテナンス</a></td></tr>";
		}
		if($_SESSION['edit_button'] || $_SESSION['mnt_button']){
			$html .= "</table>";
		}
		return $html;
	}
}
